/*
 * Author: Andrei Grigorean
 * Date: 13.05.2009
 */

#include <cassert>
#include <fstream>
#include <vector>
#include <algorithm>
using namespace std;

const int MAX_N = 100005;
const int MAX_L = 260;
const int MAX_K = 260;
const int INF = 0x3f3f3f3f;
const int MOD = 666013;

ifstream fin("trotuar.in");
ofstream fout("trotuar.out");

int n, l, k, m;
int a[MAX_K];
vector<int> bad[MAX_L];
int profile[MAX_L];
vector<int>::iterator it[MAX_L];
vector<int> zl;
int zone[MAX_L];
int c1[MAX_N];
int c2[MAX_L];

inline void checkMin(int &a, int b) { a = (a < b) ? a : b; }

bool end() {
	for (int i = 1; i <= l; ++i)
		if (profile[i] != n + 1)
			return false;
	return true;
}

bool smooth() {
	for (int i = 2; i <= l; ++i)
		if (profile[i] != profile[1])
			return false;
	return true;
}

int getMin() {
	int ret = INF;
	for (int i = 1; i <= l; ++i)
		checkMin(ret, profile[i]);
	return ret;
}

int mod(long long x) { return (int)(x % MOD); }

void knapsack() {
	c2[0] = 1;
	for (int i = 1; i <= l; ++i)
		for (int j = 1; j <= k; ++j)
			if (i >= a[j])
				c2[i] = mod((long long)c2[i] + c2[i - a[j]]);

	for (int i = 1; i <= k; ++i)
		if (a[i] == l)
			--c2[l];
	c2[l] = mod(c2[l] + MOD);

	c1[0] = 1;
	for (int i = 1; i <= n; ++i) {
		if (i >= l)
			c1[i] = mod(((long long)c1[i - l]) * c2[l]);
		for (int j = 1; j <= k; ++j)
			if (i >= a[j])
				c1[i] = mod((long long)c1[i] + c1[i - a[j]]);
	}
}

int main() {
	fin >> n >> l >> k >> m;
	for (int i = 1; i <= k; ++i)
		fin >> a[i];

	for (int i = 1; i <= m; ++i) {
		int x, y;
		fin >> x >> y;
		bad[y].push_back(x);
	}
	for (int i = 1; i <= l; ++i)
		bad[i].push_back(n + 1);
	for (int i = 1; i <= l; ++i)
		sort(bad[i].begin(), bad[i].end());
	for (int i = 1; i <= l; ++i)
		it[i] = bad[i].begin();

	knapsack();

	for (int i = 1; i <= l; ++i)
		profile[i] = 1;
	while (!end()) {
		if (smooth()) {
			int min = INF;
			for (int i = 1; i <= l; ++i)
				checkMin(min, *it[i]);

			if (min > profile[1])
				zl.push_back(min - profile[1]);

			for (int i = 1; i <= l; ++i) {
				profile[i] = min;
				while (*it[i] == profile[i] && profile[i] <= n) {
					++it[i];
					++profile[i];
				}
			}
		}
		else {
			int min = getMin();

			for (int p1 = 1, p2 = 1; p1 <= l; p1 = ++p2) {
				while (p2 < l && profile[p2 + 1] == profile[p1])
					++p2;
				if (profile[p1] < min + l && profile[p1] < n + 1)
					++zone[p2 - p1 + 1];
			}

			for (int i = 1; i <= l; ++i)
				if (profile[i] < min + l) {
					profile[i] += l;
                    assert(profile[i] <= n + 1);
                    assert(profile[i] <= *it[i]);
					while (*it[i] == profile[i] && profile[i] <= n) {
						++it[i];
						++profile[i];
					}
				}
		}
	}

	long long ret = 1;
	for (int i = 1; i < l; ++i)
		for (int j = 1; j <= zone[i]; ++j)
			ret = mod(ret * c2[i]);
	for (vector<int>::iterator it = zl.begin(); it != zl.end(); ++it)
		ret = mod(ret * c1[*it]);

	fout << ret << "\n";
}
